@@ -165,11 +165,10 @@ flames_backfit(
   double maxdiscardfract=0;
   char bkgfitmethod[CATREC_LEN+1];
   int32_t negativepixels=0;
-  frame_data pixelvalue=0;
 
-  frame_data *fdvecbuf1=0;
-  frame_data *fdvecbuf2=0;
-  frame_data *fdvecbuf3=0;
+
+
+
   frame_mask *fmvecbuf1=0;
 
   memset(output, 0, 200);
@@ -204,16 +203,16 @@ flames_backfit(
   }
 
   /* get input frame name from MIDAS env.*/
-  status = SCKGETC(FRAMENAME,1,CATREC_LEN+1,&nval,infile);
+  SCKGETC(FRAMENAME,1,CATREC_LEN+1,&nval,infile);
 
   /* read input table name */
-  status = SCKGETC(BACKTABLE,1,160,&nval,backfile);
+  SCKGETC(BACKTABLE,1,160,&nval,backfile);
 
   /* read order table name */
-  status = SCKGETC(ORDERTABLE,1,160,&nval,orderfile);
+  SCKGETC(ORDERTABLE,1,160,&nval,orderfile);
 
   /* read output fitted background frame name */
-  status = SCKGETC(BACKFRAME,1,160,&nval,backframefile);
+  SCKGETC(BACKFRAME,1,160,&nval,backframefile);
 
   /* initialise background fitting scalars */
   if (SCKRDI(BKGPOL, 1, 1, &actvals, &bxdegree, &unit, &null) 
@@ -479,10 +478,11 @@ BKGBADSCAN");
        standard deviation: if the negative value is compatible with zero, 
        set that pixel to zero, otherwise mark that pixel as bad */
     negativepixels=0;
-    fdvecbuf1 = ScienceFrame->frame_array[0];
-    fdvecbuf2 = ScienceFrame->frame_sigma[0];
+    frame_data* fdvecbuf1 = ScienceFrame->frame_array[0];
+    frame_data* fdvecbuf2 = ScienceFrame->frame_sigma[0];
     fmvecbuf1 = ScienceFrame->badpixel[0];
-    fdvecbuf3 = backframe[0];
+    frame_data* fdvecbuf3 = backframe[0];
+    frame_data pixelvalue=0;
     for (i=0; i<=((ScienceFrame->subrows*ScienceFrame->subcols)-1); i++) {
       if (fmvecbuf1[i]==0 && (pixelvalue=(fdvecbuf1[i]-fdvecbuf3[i]))<0) {
 	if ((pixelvalue*pixelvalue)>fdvecbuf2[i]) {
