@@ -1267,12 +1267,13 @@ int uves_parameters_get_int( cpl_parameterlist* list,
   char * recipename =NULL;
   cpl_parameter* p =NULL;
   int result = 0;
+  assure(list != NULL,CPL_ERROR_NULL_INPUT,"parameters list is NULL");
+  assure(recipe_id != NULL,CPL_ERROR_NULL_INPUT,"input recipe id is NULL");
+  assure(name != NULL,CPL_ERROR_NULL_INPUT,"input param name is NULL");
 
   sprintf(recipename,"xsh.%s",recipe_id);
   sprintf(paramname,"%s.%s",recipename,name);
 
-  assure(list != NULL,CPL_ERROR_NULL_INPUT,"parameters list is NULL");
-
   check_nomsg(p = cpl_parameterlist_find( (cpl_parameterlist *)list,paramname));
   check_nomsg(result = cpl_parameter_get_int(p));
 
