@@ -1,21 +1,21 @@
 /*===========================================================================
   Copyright (C) 2001 European Southern Observatory (ESO)
- 
+
   This program is free software; you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as 
   published by the Free Software Foundation; either version 2 of 
   the License, or (at your option) any later version.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   You should have received a copy of the GNU General Public 
   License along with this program; if not, write to the Free 
   Software Foundation, Inc., 675 Massachusetss Ave, Cambridge, 
   MA 02139, USA.
- 
+
   Corresponding concerning ESO-MIDAS should be addressed as follows:
     Internet e-mail: midas@eso.org
     Postal address: European Southern Observatory
@@ -221,7 +221,7 @@ int flames_mainoptFF(const char *IN_A,
     flames_err status=0;
 
     flames_frame *AllFrame=0;
- 
+
     allslitflats *Slit_FF=0;
 
     allflats *Shifted_FF=0;
@@ -271,7 +271,7 @@ int flames_mainoptFF(const char *IN_A,
     int32_t reallastorder=0;
     int32_t slitfirstorder=0;
     int32_t slitlastorder=0;
-    double oldyshift=0;
+
     double newyshift=0;
     int32_t negativepixels=0;
     char bkginline=TRUE;
@@ -298,31 +298,31 @@ int flames_mainoptFF(const char *IN_A,
     bkgswitch = USEALL;
 
     SCSPRO("optnorm"); /* Get into MIDAS Env. */
- 
+
     /* Read once and for all, here at the beginning, what MIDAS keywords we 
        need */
 
     /* get input frame name from MIDAS env.*/
-    status = SCKGETC(IN_A,1,CATREC_LEN+1,&nval,infile);
+    SCKGETC(IN_A,1,CATREC_LEN+1,&nval,infile);
 
     /* get the fibre FF catalog name from MIDAS env.*/  
-    status = SCKGETC_fs(IN_B,1,CATREC_LEN+1,&nval,&allfile);
+    SCKGETC_fs(IN_B,1,CATREC_LEN+1,&nval,&allfile);
 
     /* get the slit FF catalog name from MIDAS env.*/
-    status = SCKGETC_fs(IN_C,1,CATREC_LEN+1,&nval,&slitsfile);
+    SCKGETC_fs(IN_C,1,CATREC_LEN+1,&nval,&slitsfile);
 
     /* read background inter-order table name */
-    status = SCKGETC(IN_D,1,160,&nval,backfile);
+    SCKGETC(IN_D,1,160,&nval,backfile);
 
     /* read input order table name */
-    status = SCKGETC(IN_E,1,160,&nval,dummyfile);
+    SCKGETC(IN_E,1,160,&nval,dummyfile);
     if (striptblext(dummyfile, inorderfile) != NOERR) {
         SCTPUT("Error stripping extension from input order table file name");
         return flames_midas_fail();
     }
 
     /* read output order table name */
-    status = SCKGETC(IN_F,1,160,&nval,dummyfile);
+    SCKGETC(IN_F,1,160,&nval,dummyfile);
     if (striptblext(dummyfile, outorderfile) != NOERR) {
         SCTPUT("Error stripping extension from output order table file name");
         return flames_midas_fail();
@@ -346,14 +346,14 @@ int flames_mainoptFF(const char *IN_A,
 
     /* initialise MAXDISCARDFRACT from keyword */
     if (SCKRDD(MAXDISCARDFRACT, 1, 1, &actvals, &maxdiscardfract, &unit, 
-               &null) != 0) {
+                    &null) != 0) {
         /* problems reading MAX_DISCARD_FRACT */
         SCTPUT("Error reading the MAXDISCARDFRACT keyword");
         return flames_midas_fail();
     }
     /* initialise MAXBACKITERS from keyword */
     if (SCKRDI(MAXBACKITERS, 1, 1, &actvals, &maxbackiters, &unit, 
-               &null) != 0) {
+                    &null) != 0) {
         /* problems reading MAX_BACK_ITERS */
         SCTPUT("Error reading the MAX_BACK_ITERS keyword");
         return flames_midas_fail();
@@ -361,7 +361,7 @@ int flames_mainoptFF(const char *IN_A,
 
     /* initialise MAXCORRITERS from keyword */
     if (SCKRDI(MAXCORRITERS, 1, 1, &actvals, &imaxcorriters, &unit, 
-               &null) != 0) {
+                    &null) != 0) {
         /* problems reading MAX_CORR_ITERS */
         SCTPUT("Error reading the MAX_CORR_ITERS keyword");
         return flames_midas_fail();
@@ -418,13 +418,13 @@ back to 0");
 
     /* initialise background fitting scalars */
     if (SCKRDI(BKGPOL, 1, 1, &actvals, &bxdegree, &unit, &null) 
-        != 0) {
+                    != 0) {
         /* problems reading xdegree */
         SCTPUT("Error reading the x degree of the background polynomial");
         return flames_midas_fail();
     }
     if (SCKRDI(BKGPOL, 2, 1, &actvals, &bydegree, &unit, &null) 
-        != 0) {
+                    != 0) {
         /* problems reading xdegree */
         SCTPUT("Error reading the y degree of the background polynomial");
         return flames_midas_fail();
@@ -440,7 +440,7 @@ back to 0");
     case 'C':
         /* it exists and it is a character keyword, do read it */
         if (SCKGETC(BKGFITINLINE, 1, CATREC_LEN, &nval, bkgfitmethod) 
-            != 0) {
+                        != 0) {
             /* problems reading BKGFITINLINE */
             SCTPUT("Warning: error reading the BKGFITINLINE keyword, falling back to \
 default");
@@ -457,7 +457,7 @@ default");
                 if (strncmp("YES", bkgfitmethod, (size_t) nval) == 0)
                     bkginline = TRUE;
                 else if (strncmp("NO", bkgfitmethod, (size_t) nval)
-                         == 0) bkginline = FALSE;
+                                == 0) bkginline = FALSE;
                 else {
                     SCTPUT("Warning: unsupported BKGFITINLINE value, falling back to \
 default");
@@ -486,7 +486,7 @@ default");
     case 'C':
         /* it exists and it is a character keyword, go ahead and read it */
         if (SCKGETC(BKGFITMETHOD, 1, CATREC_LEN, &nval, bkgfitmethod) 
-            != 0) {
+                        != 0) {
             /* problems reading BKGFITMETHOD */
             SCTPUT("Warning: error reading the BKGFITMETHOD keyword, falling back to \
 default");
@@ -504,11 +504,11 @@ default");
                 if (strncmp("ALL", bkgfitmethod, (size_t) nval) == 0)
                     bkgswitch = USEALL;
                 else if (strncmp("MEDIAN", bkgfitmethod, (size_t) nval)
-                         == 0) bkgswitch = USEMEDIAN;
+                                == 0) bkgswitch = USEMEDIAN;
                 else if (strncmp("MINIMUM", bkgfitmethod, (size_t) nval)
-                         == 0) bkgswitch = USEMINIMUM;
+                                == 0) bkgswitch = USEMINIMUM;
                 else if (strncmp("AVERAGE", bkgfitmethod, (size_t) nval)
-                         == 0) bkgswitch = USEAVERAGE;
+                                == 0) bkgswitch = USEAVERAGE;
                 else {
                     SCTPUT("Warning: unsupported BKGFITMETHOD value, falling back to \
 default");
@@ -537,7 +537,7 @@ default");
     case 'C':
         /* it exists and it is a character keyword, go ahead and read it */
         if (SCKGETC(BKGBADSCAN, 1, CATREC_LEN, &nval, bkgfitmethod) 
-            != 0) {
+                        != 0) {
             /* problems reading BKGFITMETHOD */
             SCTPUT("Warning: error reading the BKGBADSCAN keyword, falling back to \
 default");
@@ -555,9 +555,9 @@ default");
                 if (strncmp("NONE", bkgfitmethod, (size_t) nval) == 0)
                     bkgswitch2 = NOBADSCAN;
                 else if (strncmp("FRACTION", bkgfitmethod, (size_t) nval)
-                         == 0) bkgswitch2 = FRACBADSCAN;
+                                == 0) bkgswitch2 = FRACBADSCAN;
                 else if (strncmp("ABSOLUTE", bkgfitmethod, (size_t) nval)
-                         == 0) bkgswitch2 = ABSBADSCAN;
+                                == 0) bkgswitch2 = ABSBADSCAN;
                 else {
                     SCTPUT("Warning: unsupported BKGBADSCAN value, falling back to \
 default");
@@ -579,13 +579,13 @@ default");
        keywords needed */
     if (bkgswitch2 == FRACBADSCAN) {
         if ((SCKRDI(BKGBADWIN, 1, 1, &actvals, &badwinxsize, &unit, &null) != 0)
-            || (SCKRDI(BKGBADWIN, 2, 1, &actvals, &badwinysize, &unit, &null) 
-                != 0)) {
+                        || (SCKRDI(BKGBADWIN, 2, 1, &actvals, &badwinysize, &unit, &null)
+                                        != 0)) {
             SCTPUT("Error reading the BKGBADWIN keyword");
             return flames_midas_fail();
         }
         if (SCKRDD(BKGBADMAXFRAC, 1, 1, &actvals, &badfracthres, &unit, 
-                   &null) != 0) {
+                        &null) != 0) {
             SCTPUT("Error reading the BKGBADMAXFRAC keyword");
             return flames_midas_fail();
         }
@@ -603,13 +603,13 @@ BKGBADSCAN");
     }
     else if (bkgswitch2 == ABSBADSCAN) {
         if ((SCKRDI(BKGBADWIN, 1, 1, &actvals, &badwinxsize, &unit, &null) != 0)
-            || (SCKRDI(BKGBADWIN, 2, 1, &actvals, &badwinysize, &unit, &null) 
-                != 0)) {
+                        || (SCKRDI(BKGBADWIN, 2, 1, &actvals, &badwinysize, &unit, &null)
+                                        != 0)) {
             SCTPUT("Error reading the BKGBADWIN keyword");
             return flames_midas_fail();
         }
         if (SCKRDI(BKGBADMAXTOT, 1, 1, &actvals, &badtotthres, &unit, 
-                   &null) != 0) {
+                        &null) != 0) {
             SCTPUT("Error reading the BKGBADMAXTOT keyword");
             return flames_midas_fail();
         }
@@ -643,7 +643,7 @@ BKGBADSCAN");
         SCTPUT("Allocation error during AllFrame memory allocation");
         return flames_midas_fail();   
     }
-   
+
     /* let's read the Science Frame */
     sprintf(output, "I'm reading the frame %s", infile);
     SCTPUT(output);
@@ -720,7 +720,7 @@ BKGBADSCAN");
        was required*/
     lastiyixindex = (AllFrame->subrows*AllFrame->subcols)-1;
     backframe = fdmatrix(0, AllFrame->subrows-1, 0, 
-                         AllFrame->subcols-1);
+                    AllFrame->subcols-1);
     memset(&backframe[0][0], 0, 
            AllFrame->subrows*AllFrame->subcols*sizeof(frame_data));
 
@@ -736,7 +736,7 @@ BKGBADSCAN");
 
         /* read in the background table */
         if ((status=readback(&(AllFrame->back), backfile, bxdegree, bydegree)) 
-            != NOERR) {
+                        != NOERR) {
             /* something went wrong while reading the background table */
             sprintf(output, "Error %d while reading the background table", status);
             SCTPUT(output);
@@ -745,15 +745,15 @@ BKGBADSCAN");
 
 
         /* Calculate the fit model of the background */ 
- 
+
         SCTPUT("Start the background fitting procedure");
 
         if (AllFrame->back.Window_Number > 0) {
-     
+
 
             if (scatter(AllFrame, Order, bkgswitch, bkgswitch2, badwinxsize, 
-                        badwinysize, badfracthres, badtotthres, kappa2, 
-                        (int32_t) maxbackiters, maxdiscardfract, OUTPUTI)) {
+                            badwinysize, badfracthres, badtotthres, kappa2,
+                            (int32_t) maxbackiters, maxdiscardfract, OUTPUTI)) {
                 SCTPUT("Error executing the scatter function");
                 return flames_midas_fail();   
             }
@@ -889,22 +889,22 @@ frame(s)");
         if (Order->firstorder<realfirstorder) {
             iorderifibreixstart = 0;
             iorderifibreixend = ((realfirstorder-Order->firstorder)*
-                                 Single_FF->maxfibres*Single_FF->subcols)-1;
+                            Single_FF->maxfibres*Single_FF->subcols)-1;
             for (ix=iorderifibreixstart; ix<=iorderifibreixend; ix++) {
                 fmvecbuf1[ix] = BADSLICE;
             }
         }
         if (Order->lastorder>reallastorder) {
             iorderifibreixstart = (reallastorder-Order->firstorder+1)*
-                Single_FF->maxfibres*Single_FF->subcols;
+                            Single_FF->maxfibres*Single_FF->subcols;
             iorderifibreixend = ((Order->lastorder-Order->firstorder)*
-                                 Single_FF->maxfibres*Single_FF->subcols)-1;
+                            Single_FF->maxfibres*Single_FF->subcols)-1;
             for (ix=iorderifibreixstart; ix<=iorderifibreixend; ix++) {
                 fmvecbuf1[ix] = BADSLICE;
             }
         }
 
-        oldyshift = 0;
+        double oldyshift = 0;
         if (AllFrame->nflats != 0) {
             for (iframe=0; iframe<=(AllFrame->nflats-1); iframe++) 
                 oldyshift += AllFrame->yshift[iframe];
@@ -927,8 +927,8 @@ frame(s)");
         deltas = dvector(0, Single_FF->nflats-1);
         deltamask = fmvector(0, Single_FF->nflats-1);
         if (gausscorrelFF(AllFrame, Single_FF, Order, maxcorriters, shiftwindow, 
-                          shifttol, correlxstep, "middumma.fits", deltas, 
-                          deltamask)) {
+                        shifttol, correlxstep, "middumma.fits", deltas,
+                        deltamask)) {
             SCTPUT("Error during cross-correlation calculation");
             return flames_midas_fail();
         }
@@ -1016,16 +1016,16 @@ table being used do not overlap at all!");
         if (Order->firstorder<realfirstorder) {
             iorderifibreixstart = 0;
             iorderifibreixend = (realfirstorder-Order->firstorder)*
-                Single_FF->maxfibres*Single_FF->subcols-1;
+                            Single_FF->maxfibres*Single_FF->subcols-1;
             for (ix=iorderifibreixstart; ix<=iorderifibreixend; ix++) {
                 fmvecbuf1[ix] = BADSLICE;
             }
         }
         if (Order->lastorder>reallastorder) {
             iorderifibreixstart = (reallastorder-Order->firstorder+1)*
-                Single_FF->maxfibres*Single_FF->subcols;
+                            Single_FF->maxfibres*Single_FF->subcols;
             iorderifibreixend = (Order->lastorder-Order->firstorder)*
-                Single_FF->maxfibres*Single_FF->subcols-1;
+                            Single_FF->maxfibres*Single_FF->subcols-1;
             for (ix=iorderifibreixstart; ix<=iorderifibreixend; ix++) {
                 fmvecbuf1[ix] = BADSLICE;
             }
@@ -1074,12 +1074,12 @@ table being used do not overlap at all!");
             AllFrame->yshift[iframe]=0;
             /* try to open the single FF frame */
             if (SCFOPN(Single_FF->flatdata[iframe].framename, FLAMESDATATYPE, 0, 
-                       F_IMA_TYPE, &fileid) != 0) {
+                            F_IMA_TYPE, &fileid) != 0) {
                 /* I could not open the frame */
                 return flames_midas_fail();
             }
             if (SCDWRD(fileid, "YSHIFT", &Single_FF->flatdata[iframe].yshift,
-                       1, 1, &unit) != 0) {
+                            1, 1, &unit) != 0) {
                 /* error writing YSHIFT */
                 return flames_midas_fail();
             }
@@ -1091,7 +1091,7 @@ table being used do not overlap at all!");
 
         /* try to open the all fibres FF frame */
         if (SCFOPN(AllFrame->framename, FLAMESDATATYPE, 0, F_IMA_TYPE, 
-                   &fileid) != 0) {
+                        &fileid) != 0) {
             /* I could not open the frame */
             return flames_midas_fail();
         }
@@ -1101,7 +1101,7 @@ table being used do not overlap at all!");
             return flames_midas_fail();
         }
         if (SCDWRD(fileid, "YSHIFT", AllFrame->yshift, 1, 
-                   nflats, &unit) != 0) {
+                        nflats, &unit) != 0) {
             /* error writing descriptor */
             return flames_midas_fail();
         }
@@ -1119,7 +1119,7 @@ table being used do not overlap at all!");
         }
         /* find the extremal lit fibres */
         for (ifibre=0; (ifibre<=Single_FF->maxfibres-1) && 
-                 (Single_FF->fibremask[ifibre]!=TRUE); ifibre++);
+        (Single_FF->fibremask[ifibre]!=TRUE); ifibre++);
         if (ifibre<=Single_FF->maxfibres-1) {
             firstfibre = lastfibre = ifibre;
             for (ifibre++; ifibre<=Single_FF->maxfibres-1; ifibre++)
@@ -1140,7 +1140,7 @@ table being used do not overlap at all!");
         }
         /* now write the changed descriptors */
         if (SCDWRD(tid, "FIBREPOS", Order->fibrepos, 1, Order->maxfibres, &unit) 
-            != 0) {
+                        != 0) {
             SCTPUT("Error writing corrected FIBREPOS descriptor");
             return flames_midas_fail();
         }
@@ -1153,7 +1153,7 @@ table being used do not overlap at all!");
             return flames_midas_fail();
         }
         if (SCDWRD(tid, "TAB_IN_OUT_YSHIFT", &Order->tab_io_yshift, 1, 1, &unit) 
-            !=0) {
+                        !=0) {
             SCTPUT("Error updating TAB_IN_OUT_YSHIFT descriptor");
             return flames_midas_fail();
         }
@@ -1200,15 +1200,15 @@ table being used do not overlap at all!");
             Shifted_FF->flatdata[iframe+1].data = Single_FF->flatdata[iframe].data;
             Shifted_FF->flatdata[iframe+1].sigma = Single_FF->flatdata[iframe].sigma;
             Shifted_FF->flatdata[iframe+1].badpixel = 
-                Single_FF->flatdata[iframe].badpixel;
+                            Single_FF->flatdata[iframe].badpixel;
             Shifted_FF->flatdata[iframe+1].framename = 
-                Single_FF->flatdata[iframe].framename;
+                            Single_FF->flatdata[iframe].framename;
             Shifted_FF->flatdata[iframe+1].sigmaname = 
-                Single_FF->flatdata[iframe].sigmaname;
+                            Single_FF->flatdata[iframe].sigmaname;
             Shifted_FF->flatdata[iframe+1].badname = 
-                Single_FF->flatdata[iframe].badname;
+                            Single_FF->flatdata[iframe].badname;
             Shifted_FF->flatdata[iframe+1].fibres = 
-                Single_FF->flatdata[iframe].fibres;
+                            Single_FF->flatdata[iframe].fibres;
         }
         /* handle the last iframe differently */
         iframe = Shifted_FF->nflats-1;
@@ -1286,10 +1286,10 @@ table being used do not overlap at all!");
     /* copy the normalisation factors from the slit FF structure before 
        freeing it for good */
     normcover = fdmatrix(0, Slit_FF->lastorder-Slit_FF->firstorder, 
-                         0, Slit_FF->subcols-1);
+                    0, Slit_FF->subcols-1);
     memcpy(normcover[0], Slit_FF->normfactor[0], 
            (size_t) ((Slit_FF->lastorder-Slit_FF->firstorder+1)*
-                     Slit_FF->subcols)*sizeof(frame_data));
+                           Slit_FF->subcols)*sizeof(frame_data));
     /* finally free for good the memory for the slit FF */
     if (freeslitflats(Slit_FF)!=NOERR) {
         SCTPUT("Error while freeing the memory for the Slit_FF structure");
@@ -1314,7 +1314,7 @@ table being used do not overlap at all!");
         /* read in the old background table */
         SCTPUT("A significant drift was detected:\n refit the background");
         if ((status=readback(&(AllFrame->back), backfile, bxdegree, bydegree)) 
-            != NOERR) {
+                        != NOERR) {
             /* something went wrong while reading the background table */
             sprintf(output, "Error %d while reading the background table", status);
             SCTPUT(output);
@@ -1322,8 +1322,8 @@ table being used do not overlap at all!");
         }
         if (AllFrame->back.Window_Number > 0) {
             if (scatter(AllFrame, Order, bkgswitch, bkgswitch2, badwinxsize, 
-                        badwinysize, badfracthres, badtotthres, kappa2, 
-                        (int32_t) maxbackiters, maxdiscardfract, OUTPUTI)) {
+                            badwinysize, badfracthres, badtotthres, kappa2,
+                            (int32_t) maxbackiters, maxdiscardfract, OUTPUTI)) {
                 SCTPUT("Error during the calculation of the scattered light");
                 return flames_midas_fail();
             }
@@ -1399,8 +1399,8 @@ initialisations ***\n");
     /* Going to do the real spectrum extraction */
     SCTPUT("\n*** Step 4: optimal extraction proper ***\n");
     if (doptimal(AllFrame, Order, Shifted_FF, kappa2, mask, backframe, 
-                 normcover, orderoffset, realfirstorder, reallastorder,
-                 minoptitersint, maxoptitersint, xkillsize, ykillsize)!=NOERR) {
+                    normcover, orderoffset, realfirstorder, reallastorder,
+                    minoptitersint, maxoptitersint, xkillsize, ykillsize)!=NOERR) {
         SCTPUT("Error in doptimal");
         return flames_midas_fail();
     }
@@ -1412,7 +1412,7 @@ initialisations ***\n");
 
     /* build the fitted all fibres FF Frame, do it in place to save memory */
     if (optsynth(AllFrame, Shifted_FF, Order, &backframe, &chisquare, 
-                 &chisqpixels, &nfittedparams)!=NOERR) {
+                    &chisqpixels, &nfittedparams)!=NOERR) {
         SCTPUT("Error computing the fitted frame");
         return flames_midas_fail();
     }
@@ -1423,7 +1423,7 @@ initialisations ***\n");
     SCTPUT("Writing the synthesized sigma frame to middummc.bdf");
     SCTPUT("Writing the overall mask to middummd.bdf");
     if (writesynth(AllFrame, "middummb.bdf", "middummc.bdf", "middummd.bdf")
-        != NOERR)
+                    != NOERR)
         SCTPUT("Warning: error writing dummy debugging frames");
 
 
@@ -1448,21 +1448,21 @@ exit ***\n");
     fmvecbuf2 = AllFrame->specmask[0][0];
     for (ifibre=0; ifibre<=(Shifted_FF->maxfibres-1); ifibre++) {
         if ((Shifted_FF->fibremask[ifibre]==TRUE) &&
-            (AllFrame->fibremask[ifibre]==TRUE)) {
+                        (AllFrame->fibremask[ifibre]==TRUE)) {
             for (iorder=0; iorder<=(Order->lastorder-Order->firstorder); iorder++) {
                 iorderifibreindex = (iorder*AllFrame->maxfibres)+ifibre;
                 iorderifibreixoffset = iorderifibreindex*AllFrame->subcols;
                 for (ix=0; ix<=(Shifted_FF->subcols-1); ix++) {
                     iorderifibreixindex = iorderifibreixoffset+ix;
                     ixiorderifibreindex = (ix*(1+Order->lastorder-Order->firstorder)*
-                                           AllFrame->maxfibres)+iorderifibreindex;
+                                    AllFrame->maxfibres)+iorderifibreindex;
                     /* was this a decent fibre at this x, before? */
                     if (fmvecbuf1[iorderifibreixindex] != BADSLICE) {
                         pixelvalue = fdvecbuf3[ixiorderifibreindex];
                         /* was I able to extract this with a decent SNR? */
                         if ((fmvecbuf2[ixiorderifibreindex]==1) &&
-                            ((pixelvalue*pixelvalue/fdvecbuf4[ixiorderifibreindex])
-                             >=decentSNR2)){
+                                        ((pixelvalue*pixelvalue/fdvecbuf4[ixiorderifibreindex])
+                                                        >=decentSNR2)){
                             fmvecbuf1[iorderifibreixindex] = GOODSLICE;
                             fdvecbuf1[iorderifibreixindex] = fdvecbuf3[ixiorderifibreindex];
                             fdvecbuf2[iorderifibreixindex] = fdvecbuf4[ixiorderifibreindex];
