@@ -111,8 +111,8 @@ int flames_prepframe(const char *FRAMENAME, const char *SATFILTER,
     char keytype = 0;
     char framename[CATREC_LEN + 5];char
     badpxframe[CATREC_LEN + 5];char
-    filterswitch[161];
-    char satfilter[161];
+    filterswitch[CATREC_LEN];
+    char satfilter[CATREC_LEN];
     filtertype filter = NONE;
     char filter2 = FALSE;
     int32_t i = 0;
@@ -131,8 +131,8 @@ int flames_prepframe(const char *FRAMENAME, const char *SATFILTER,
 
     memset(framename, 0, CATREC_LEN + 5);
     memset(badpxframe, 0, CATREC_LEN + 5);
-    memset(filterswitch, 0, 161);
-    memset(satfilter, 0, 161);
+    memset(filterswitch, 0, CATREC_LEN);
+    memset(satfilter, 0, CATREC_LEN);
     uves_msg_debug("FRAMENAME: %s", FRAMENAME);
     uves_msg_debug("SATFILTER: %s", SATFILTER);
     uves_msg_debug("FILTERSWITCH: %s", FILTERSWITCH);
