@@ -107,7 +107,7 @@ The solid and dashed horizontal lines represent the median value and the +-1 sig
         
         #YDIF vs XDIF plot
         title_ydif_xdif   = '' 
-        tooltip_ydif_xdif ="""Plot of the difference between the measured and predicted line Y coordinate (pix) versus the difference between the measured and predicted line X coordinate (pix).
+        tooltip_ydif_xdif ="""Plot of the difference between the measured and predicted line Y coordinate (pix) versus the difference between the measured and predicted line X coordinate (pix). Red points refer to REDU arm.
 The solid horizontal and vertical lines represent the median values of the differences YDIF and XDIF respectively."""
         self.line_guess.plotYDIFvsXDIF(self.subplot_ydif_xdif, title_ydif_xdif, tooltip_ydif_xdif)
 
@@ -172,7 +172,7 @@ if __name__ == '__main__':
   import uves_plot_common
 
   # Create interactive application
-  interactive_app = reflex_interactive_app.PipelineInteractiveApp()
+  interactive_app = reflex_interactive_app.PipelineInteractiveApp(enable_init_sop=True)
 
   #Check if import failed or not
   if import_sucess == False :
