@@ -513,7 +513,7 @@ class PlotableRedLineGuessTable(ScatterPlot):
   def plotYDIFvsXDIF(self, subplot, title, tooltip) :
     self.setLabels(subplot, 'XDIF [pix]', 'YDIF [pix]')
     self.scatterPlotScatterSmall(subplot, self.tab_high.xdif_sel, self.tab_high.ydif_sel)
-    self.scatterPlotScatterSmall(subplot, self.tab_low.xdif_sel, self.tab_low.ydif_sel)
+    self.scatterPlotScatterSmall(subplot, self.tab_low.xdif_sel, self.tab_low.ydif_sel,'red')
     subplot.axhline(y=self.median_all_ydif, color='black', lw=1.2)
     subplot.axvline(x=self.median_all_xdif, color='black', lw=1.2)
     self.finalSetup(subplot, title, tooltip)
