@@ -353,6 +353,7 @@ class PlotableBlueLineGuessTable(PlotableLineGuessTable):
     subplot.set_ylim(0., self.det_nx)
     self.finalSetup(subplot, title, tooltip)
  
+
 class PlotableRedLineGuessTable(ScatterPlot):
   def __init__(self, fits_low, fits_high):
     self.tab_low = PlotableLineGuessTable(fits_low)
@@ -510,7 +511,7 @@ class PlotableRedLineGuessTable(ScatterPlot):
   def plotYDIFvsXDIF(self, subplot, title, tooltip) :
     self.setLabels(subplot, 'XDIF [pix]', 'YDIF [pix]')
     self.scatterPlotScatterSmall(subplot, self.tab_high.xdif_sel, self.tab_high.ydif_sel)
-    self.scatterPlotScatterSmall(subplot, self.tab_low.xdif_sel, self.tab_low.ydif_sel)
+    self.scatterPlotScatterSmall(subplot, self.tab_low.xdif_sel, self.tab_low.ydif_sel,'red')
     subplot.axhline(y=self.median_all_ydif, color='black', lw=1.2)
     subplot.axvline(x=self.median_all_xdif, color='black', lw=1.2)
     self.finalSetup(subplot, title, tooltip)
