@@ -27,6 +27,9 @@
 #define MIN_NAME_SIZE  80      /* fixme: Is this always enough? */
 #define MED_NAME_SIZE 255      /* fixme: Is this always enough? */
 
+#define cpl_frameset_get_frame cpl_frameset_get_position
+#define cpl_frameset_get_frame_const cpl_frameset_get_position_const
+
 #include <stdint.h>
 
 #endif /* UVES_GLOBALS_H */
