@@ -1155,6 +1155,8 @@ uves_orderpos_exe_body(cpl_frameset *frames,
 
     int i=0;
     int j=0;
+    char extname[80];
+    uves_propertylist* table_header = NULL;
 
 
     /* Read recipe parameters */
@@ -1271,7 +1273,7 @@ uves_orderpos_exe_body(cpl_frameset *frames,
 	chip = uves_chip_get_next(chip);
       }
 
-
+        table_header = uves_propertylist_new();
 
         raw_index = uves_chip_get_index(chip);
         norders = 0;                           /* Number of orders detected */
@@ -1504,7 +1506,10 @@ uves_orderpos_exe_body(cpl_frameset *frames,
             uves_propertylist_append_string(product_header,
                                             "HISTORY", " ");
         }
-        
+        uves_pfits_set_extname(product_header,"Order table");
+        uves_pfits_set_extname(product_header,"Guess order table");
+        sprintf(extname,"ORDER_TAB");
+        uves_pfits_set_extname(table_header,extname);
         check(( cpl_free(product_filename),
             product_filename = uves_order_table_filename(chip),
             uves_frameset_insert(frames,
@@ -1516,7 +1521,7 @@ uves_orderpos_exe_body(cpl_frameset *frames,
                      UVES_ORD_TAB(flames, chip),
                      raw_header[raw_index],
                      product_header,
-                     NULL,
+                     table_header,
                      parameters,
                      recipe_id,
                      PACKAGE "/" PACKAGE_VERSION,
@@ -1525,9 +1530,11 @@ uves_orderpos_exe_body(cpl_frameset *frames,
            "Could not add trace table %s to frameset", product_filename);
             uves_qclog_delete(&qclog[0]);
         uves_msg("Trace table %s added to frameset", product_filename);
-        
+        sprintf(extname,"ORDER_POL");
+        uves_pfits_set_extname(table_header,extname);
+
         /* Save polynomial in next extension (don't add header keywords) */
-        check( uves_save_polynomial(bivariate_fit, product_filename, NULL),
+        check( uves_save_polynomial(bivariate_fit, product_filename, table_header),
            "Could not write polynomial to file %s", product_filename);
         
         /* Original comment:
@@ -1544,11 +1551,13 @@ uves_orderpos_exe_body(cpl_frameset *frames,
         uves_free_table(&traces);
         traces = uves_ordertable_traces_new();
         uves_ordertable_traces_add(traces, 0, 0.0, 1);
-        
+        sprintf(extname,"ORDER_INFO");
+        uves_pfits_set_extname(table_header,extname);
+
         check( cpl_table_save(traces,
                       NULL,            /* Primary header, 
                               ignored when mode is IO_EXTEND */
-                      NULL,            /* Extension header               */
+                      table_header,            /* Extension header               */
                       product_filename,/* This file already exists
                               (or an error occurs)           */
                       CPL_IO_EXTEND),  /* Append to existing file        */
@@ -1592,7 +1601,7 @@ uves_orderpos_exe_body(cpl_frameset *frames,
 	chip = uves_chip_get_next(chip);
       }
 
-        
+        uves_free_propertylist(&table_header);
     } /* For each chip */
 
   cleanup:
