@@ -361,6 +361,12 @@
 #define UVES_FNOISE "ESO FNOISE"
 #define UVES_DTIME  "ESO DTIME"
 
+/* CD matrix */
+#define UVES_CD1 "CD1"
+#define UVES_CD11 "CD1_1"
+#define UVES_CD12 "CD1_2"
+#define UVES_CD21 "CD2_1"
+#define UVES_CD22 "CD2_2"
 
 /*
  *  Slit name, length/width (arcseconds)
@@ -476,7 +482,7 @@
 #define UVES_NAXIS2 "NAXIS2"
 #define UVES_STARTX "STARTX"
 #define UVES_STARTY "STARTY"
-
+#define UVES_TEL_ALT "ESO TEL ALT"
 #define UVES_OUT1NX "ESO DET OUT1 NX"
 #define UVES_OUT1NY "ESO DET OUT1 NY"
 #define UVES_OUT4NX "ESO DET OUT4 NX"
@@ -545,13 +551,17 @@ uves_pfits_set_history_val(uves_propertylist *plist, const char *name, const cha
 #endif
     ;
 
+void uves_pfits_set_cd11(uves_propertylist * plist, double value);
+void uves_pfits_set_cd12(uves_propertylist * plist, double value);
+void uves_pfits_set_cd21(uves_propertylist * plist, double value);
+void uves_pfits_set_cd22(uves_propertylist * plist, double value);
 
 bool uves_ccd_is_new(const uves_propertylist * plist);
 int uves_pfits_get_slit3_x1encoder(const uves_propertylist * plist);
 int uves_pfits_get_slit3_x2encoder(const uves_propertylist * plist);
 double uves_pfits_get_startx(const uves_propertylist * plist);
 double uves_pfits_get_starty(const uves_propertylist * plist);
-
+double uves_pfits_get_tel_alt_start(const uves_propertylist * plist);
 int uves_pfits_get_maxfibres(const uves_propertylist * plist);
 char  uves_pfits_get_chipchoice(const uves_propertylist * plist);
 const char * uves_pfits_get_origfile(const uves_propertylist * plist);
@@ -666,6 +676,10 @@ double uves_pfits_get_cdelt1(const uves_propertylist * plist);
 double uves_pfits_get_cdelt2(const uves_propertylist * plist);
 double uves_pfits_get_wstart(const uves_propertylist * plist, int order);
 double uves_pfits_get_wend(const uves_propertylist * plist, int order);
+double uves_pfits_get_wlen1(const uves_propertylist * plist);
+
+cpl_error_code uves_pfits_set_wlen1(uves_propertylist *plist, double wlen1);
+cpl_error_code uves_pfits_set_extname(uves_propertylist * plist, const char *extname);
 cpl_error_code uves_pfits_set_bunit(uves_propertylist * plist, const char *bunit);
 cpl_error_code uves_pfits_set_bscale(uves_propertylist * plist, const double bscale);
 cpl_error_code uves_pfits_set_ctype1(uves_propertylist * plist, const char *ctype1);
