@@ -281,8 +281,8 @@ uves_mflat_process_chip(const cpl_imagelist *raw_images,
             uves_msg("Skipping bias subtraction");
         }
         
-        /* Normalize to unit exposure time */
-        check( exposure_time = uves_pfits_get_exptime(current_header), 
+        /* Normalize to unit exposure time:  */
+        check( exposure_time = uves_pfits_get_exptime(current_header),
            "Error reading exposure time");
         check( gain = uves_pfits_get_gain(current_header,chip), 
            "Error reading gain value");
@@ -309,8 +309,9 @@ uves_mflat_process_chip(const cpl_imagelist *raw_images,
     /* subtract master dark if present */
     if (master_dark != NULL)
     {
-        uves_msg("Subtracting master dark");
+        uves_msg("Subtracting master dark scaled to unit exposure time");
         check_nomsg( mdark_exposure = uves_pfits_get_exptime(mdark_header));
+
         mdark_scaled=cpl_image_duplicate(master_dark);
         cpl_image_divide_scalar(mdark_scaled,mdark_exposure); 
         check( cpl_imagelist_subtract_image(raw_images_local,mdark_scaled), 
@@ -378,7 +379,7 @@ uves_mflat_process_chip(const cpl_imagelist *raw_images,
     {
         uves_msg("Skipping background subtraction");
     }
-        
+    uves_pfits_set_extname(master_flat_header,"Master flat");
   cleanup:
 
 
@@ -939,7 +940,8 @@ uves_reduce_mflat(cpl_frameset *frames, const cpl_parameterlist *parameters,
                "Error getting filename");
             strcpy(pro_filename,prefix);
             strcat(pro_filename,product_filename);
-            
+            uves_pfits_set_extname(product_header[raw_index],
+                                   "Inter-order background");
             check( uves_frameset_insert(frames,
                         background,
                         CPL_FRAME_GROUP_PRODUCT,
