@@ -608,7 +608,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
     cpl_table        *flux_table       = NULL;
 
     cpl_table        *atm_extinction   = NULL;
-
+    uves_propertylist *table_header= NULL;
     /* Line tables for sky, object, sky (UVES specific) */
     const cpl_table        *linetable[3]           = {NULL, NULL, NULL};
     const uves_propertylist *linetable_header[3]    = {NULL, NULL, NULL};
@@ -656,7 +656,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
         
     int raw_index = 0;
 
-
+    char extname[80];
     double trace_offset=0;
     int trace_number=0;
     int trace_enabled=0;
@@ -762,6 +762,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
      chip != UVES_CHIP_INVALID;
      chip = uves_chip_get_next(chip))
     {
+      table_header = uves_propertylist_new();
 
 
       if(strcmp(PROCESS_CHIP,"REDU") == 0) {
@@ -832,7 +833,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
         uves_free_propertylist(&ordertable_header);
         uves_polynomial_delete(&order_locations);
         uves_free_table       (&traces);
-    
+
         check( uves_load_ordertable(frames, 
                     false,  /* FLAMES? */
                     chip_name,
@@ -983,7 +984,9 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     /* Save response curve */
                     cpl_free(product_filename);
                     check( product_filename = uves_response_curve_filename(chip),
-                       "Error getting filename");    
+                       "Error getting filename");
+                    uves_pfits_set_extname(response_header,"instrument response");
+
                     check( uves_frameset_insert(
                            frames,
                            response_curve,
@@ -1011,7 +1014,8 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     cpl_free(product_filename);
                     check( product_filename = 
                        uves_response_curve_2d_filename(chip), 
-                       "Error getting filename");    
+                       "Error getting filename");
+                    uves_pfits_set_extname(response_header_2d,"2D instrument response");
                     check( uves_frameset_insert(
                            frames,
                            response_orders,
@@ -1050,6 +1054,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                    prod_catg=UVES_RED_STD(chip);
 
                 }
+                uves_pfits_set_extname(spectrum_header,"reduced spectrum");
                 check( uves_frameset_insert(frames,
                             reduced_spectrum,
                             CPL_FRAME_GROUP_PRODUCT,
@@ -1082,7 +1087,9 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                     check( product_filename = 
                        uves_response_efficiency_filename(chip),
                        "Error getting filename");
-                    
+                    uves_pfits_set_extname(efficiency_header,"efficiency");
+                    sprintf(extname,"EFFICIENCY");
+                    uves_pfits_set_extname(table_header,extname);
                     check( uves_frameset_insert(
                            frames,
                            efficiency,
@@ -1093,7 +1100,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                            UVES_EFFICIENCY_TABLE(chip),
                            raw_header[raw_index],
                            efficiency_header,
-                           NULL,
+                           table_header,
                            parameters,
                            make_str(UVES_RESPONSE_ID),
                            PACKAGE "/" PACKAGE_VERSION,
@@ -1111,6 +1118,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                 check( product_filename = 
                    uves_response_bkg_standard_filename(chip), 
                    "Error getting filename");
+                uves_pfits_set_extname(rotated_header[raw_index],"background");
                 check( uves_frameset_insert(frames,
                             background,
                             CPL_FRAME_GROUP_PRODUCT,
@@ -1138,6 +1146,10 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                 check( product_filename = 
                    uves_order_extract_qc_standard_filename(chip), 
                    "Error getting filename");
+                uves_pfits_set_extname(rotated_header[raw_index],"quality control table");
+                sprintf(extname,"QC_INFO");
+                uves_pfits_set_extname(table_header,extname);
+
                 check( uves_frameset_insert(frames,
                             info_tbl,
                             CPL_FRAME_GROUP_PRODUCT,
@@ -1147,7 +1159,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                             UVES_ORDER_EXTRACT_QC(chip),
                             raw_header[raw_index],
                             rotated_header[raw_index],
-                            NULL,
+                            table_header,
                             parameters,
                             make_str(UVES_RESPONSE_ID),
                             PACKAGE "/" PACKAGE_VERSION, NULL,
@@ -1174,6 +1186,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
 	chip = uves_chip_get_next(chip);
       }
 
+      uves_free_propertylist(&table_header);
 
 
 
@@ -1202,7 +1215,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
     uves_free_propertylist(&ordertable_header);
     uves_polynomial_delete(&order_locations);
     uves_free_table(&traces);
-    
+    uves_free_propertylist(&table_header);
     uves_free_table_const( &(linetable[0]) );
     uves_free_table_const( &(linetable[1]) );
     uves_free_table_const( &(linetable[2]) );
